==> 0.0.2.tar.gz: lib/yes_no_checkbox.dart <==
library yes_no_checkbox;

import 'package:flutter/material.dart';

/// CUSTOM CHECK BOX YES/NO
class CustomCheckBoxYesOrNo extends StatefulWidget {
  final Function(
    bool yes,
    bool no,
  ) onChange;

  const CustomCheckBoxYesOrNo({
    Key? key,
    required this.onChange,
  }) : super(key: key);

  @override
  State<CustomCheckBoxYesOrNo> createState() => _CustomCheckBoxYesOrNoState();
}

class _CustomCheckBoxYesOrNoState extends State<CustomCheckBoxYesOrNo> {
  final List _check = [false, false];

  @override
  void initState() {
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Row(
      children: List.generate(_check.length, (index) {
        return Flexible(
          child: Row(
            children: <Widget>[
              Text(
                index == 0 ? "Yes" : "No",
                style: const TextStyle(
                  fontWeight: FontWeight.bold,
                ),
              ),

              ///
              Checkbox(
                value: _check[index],
                onChanged: (check) {
                  setState(() {
                    if (check != null) {
                      if (index == 0) {
                        _check[0] = true;
                        _check[1] = false;
                      } else {
                        _check[0] = false;
                        _check[1] = true;
                      }
                    }
                  });

                  ///
                  widget.onChange(
                    _check[0],
                    _check[1],
                  );
                },
              ),
            ],
          ),
        );
      }),
    );
  }
}

==> 0.0.3.tar.gz: lib/yes_no_checkbox.dart <==
library yes_no_checkbox;

import 'package:flutter/material.dart';

/// CUSTOM CHECK BOX YES/NO
class CustomCheckBoxYesOrNo extends StatefulWidget {
  final Function(
    bool yes,
    bool no,
  ) onChange;

  const CustomCheckBoxYesOrNo({
    Key? key,
    required this.onChange,
  }) : super(key: key);

  @override
  State<CustomCheckBoxYesOrNo> createState() => _CustomCheckBoxYesOrNoState();
}

class _CustomCheckBoxYesOrNoState extends State<CustomCheckBoxYesOrNo>
    with AutomaticKeepAliveClientMixin {
  final List _check = [false, false];

  @override
  void initState() {
    super.initState();
  }

  @override
  bool get wantKeepAlive => true;

  @override
  Widget build(BuildContext context) {
    super.build(context);

    return Row(
      children: List.generate(_check.length, (index) {
        return Flexible(
          child: Row(
            children: <Widget>[
              Text(
                index == 0 ? "Yes" : "No",
                style: const TextStyle(
                  fontWeight: FontWeight.bold,
                ),
              ),

              ///
              Checkbox(
                value: _check[index],
                onChanged: (check) {
                  setState(() {
                    if (check != null) {
                      if (index == 0) {
                        _check[0] = true;
                        _check[1] = false;
                      } else {
                        _check[0] = false;
                        _check[1] = true;
                      }
                    }
                  });

                  ///
                  widget.onChange(
                    _check[0],
                    _check[1],
                  );
                },
              ),
            ],
          ),
        );
      }),
    );
  }
}
